# -*- coding: utf-8 -*-

def parse_options():
    from optparse import OptionParser
    opt_parser = OptionParser(
                              usage="Usage: %prog --key=<your api key> --out=<output file>")
    opt_parser.add_option("-k", "--key",
                          action="store", type="string", dest="key",
                          help ="Your Nozbe API key (see bottom of http://www.nozbe.com/account/extras)")
    opt_parser.add_option("-o", "--out",
                          action="store", type="string", dest="out",
                          help="The name of the output (XMind) file")
    opt_parser.add_option("-v", "--verbose",
                          action="store_true", dest="verbose",
                          help="Print diagnostic messages")
    opt_parser.add_option("-d", "--devel",
                          action="store", type="string", dest="devel",
                          help="Use development installation. Give --devel=user,pwd (http auth for devel site)")
    opt_parser.set_defaults(verbose = False)
    (opts, args) = opt_parser.parse_args()
    if args:
        opt_parser.error("Unknown argument")
    if not opts.key or not opts.out:
        opt_parser.error("Missing argument")
    if opts.devel:
        import re
        m = re.match("^([^,]+),([^,]+)$", opts.devel)
        if not m:
            opt_parser.error("Bad syntax for devel option (expected user,pwd)")
        opts.devel = dict(user = m.group(1), password = m.group(2))
    return opts

options = parse_options()

from mekk.nozbe2xmind import nozbe_to_xmind, NozbeLoader
from twisted.internet import reactor, defer
import logging
logging.basicConfig(level = (options.verbose and logging.DEBUG or logging.WARN))

@defer.inlineCallbacks
def main():
    try:
        yield nozbe_to_xmind(NozbeLoader(options.key, options.devel), options.out, options.devel)
        print "Saved to %s" % options.out
    except Exception, e:
        print "Failed: ", str(e)
    finally:
        reactor.stop()

reactor.callLater(0, main)
reactor.run()
